#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.13.0.1
visibility:           public
id:                   citeproc-0.13.0.1-JlZc6Sd2sgp80tuK9FIItD
key:                  citeproc-0.13.0.1-JlZc6Sd2sgp80tuK9FIItD
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  4d840d30a62d2f03afe5c9b0d8116e2b
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/citeproc-0.13.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/citeproc-0.13.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/citeproc-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.13.0.1-JlZc6Sd2sgp80tuK9FIItD
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    pandoc-types-1.23.1.2-9jgLsuZngFN3JhSzLXhKOt
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    scientific-0.3.8.1-6O6hUkglHhJ388M1FqOkp1 text-2.0.2
    text-icu-0.8.0.5-DAQB8cSSRSvAmpouRoWfx transformers-0.6.1.0
    unicode-collation-0.1.3.7-2UNvjbpCkW4ISEQ22qINA0
    uniplate-1.6.13-JHjKR1RMN7w1LfjZKHnKKi
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    xml-conduit-1.9.1.4-Jcy2U5ohgrqJE6uMy2MrNT

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

